%if 0%{?fedora}
%global with_python3 1
%else
%global with_python3 0
%endif

Name:           python-firehose
Version:        0.5
Release:        1%{?dist}
Summary:        Library for working with output from static code analyzers

License:        LGPLv2+
URL:            https://github.com/fedora-static-analysis/firehose
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python2-six
BuildRequires:  libxml2
# ^^^: for xmllint
BuildRequires:  python2-mock
# ^^^: used during selftests
%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-six
BuildRequires:  python3-mock
# ^^^: used during selftests
%endif

%global _description\
"firehose" is a Python package intended for managing the results from\
code analysis tools (e.g. compiler warnings, static analysis, linters,\
etc).\
\
It currently provides parsers for the output of gcc, clang-analyzer and\
cppcheck.  These parsers convert the results into a common data model of\
Python objects, with methods for lossless roundtrips through a provided\
XML format.  There is also a JSON equivalent.\


%description %_description

%package -n python2-firehose
Summary: %summary
Requires:  python2-six
%{?python_provide:%python_provide python2-firehose}

%description -n python2-firehose %_description

%if 0%{?with_python3}
%package -n python3-firehose
Summary:        Library for working with output from static code analyzers
Group:          Applications/System

Requires:  python3-six

%description -n python3-firehose
"firehose" is a Python package intended for managing the results from
code analysis tools (e.g. compiler warnings, static analysis, linters,
etc).

It currently provides parsers for the output of gcc, clang-analyzer and
cppcheck.  These parsers convert the results into a common data model of
Python objects, with methods for lossless roundtrips through a provided
XML format.  There is also a JSON equivalent.
%endif # with_python3


%prep
%setup -q -n firehose-%{version}

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif # with_python3


%build
%{__python} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif # with_python3


%install
%{__python} setup.py install --skip-build --root %{buildroot}

# Mark various scripts that have shebangs as executable:
chmod +x %{buildroot}/%{python_sitelib}/firehose/parsers/cppcheck.py
chmod +x %{buildroot}/%{python_sitelib}/firehose/parsers/gcc.py



%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
chmod +x %{buildroot}/%{python3_sitelib}/firehose/parsers/cppcheck.py
chmod +x %{buildroot}/%{python3_sitelib}/firehose/parsers/gcc.py
popd
%endif # with_python3


%check
%{__python} -m unittest discover -v
%if 0%{?with_python3}
pushd %{py3dir}
%{__python} -m unittest discover -v
popd
%endif # with_python3


%files -n python2-firehose
%doc README.rst lgpl-2.1.txt examples firehose.rng
%{python_sitelib}/firehose
%{python_sitelib}/firehose-%{version}-py2.?.egg-info


%if 0%{?with_python3}
%files -n python3-firehose
%doc README.rst lgpl-2.1.txt examples firehose.rng
%{python3_sitelib}/firehose
%{python3_sitelib}/firehose-%{version}-py3.?.egg-info
%endif # with_python3


%changelog
* Mon Oct 09 2017 Athos Ribeiro <athoscr@fedoraproject.org> - 0.5-1
- Update version
- Use versioned dependencies for python2
- Use github URL for sources

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 0.2-14
- Python 2 binary package renamed to python2-firehose
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.2-11
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-10
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jun  6 2013 David Malcolm <dmalcolm@redhat.com> - 0.2-3
- remove redundant clean of the buildroot

* Fri May 31 2013 David Malcolm <dmalcolm@redhat.com> - 0.2-2
- add BR on python-mock and python3-mock (for selftests)

* Mon Mar 25 2013 David Malcolm <dmalcolm@redhat.com> - 0.2-1
- initial packaging
